@@ -1,5 +1,4 @@
 /* SCCS @(#)survreg4.c	1.6 02/21/99
-/*
 ** The variant of survreg2 for penalized models
 **
 ** Input
@@ -104,12 +103,12 @@ void survreg4(int   *maxiter,   int   *nx,       int   *nvarx,
 
     int i,j;	
     int n;
-    double *newbeta,
-	   *savediag;
-    double temp;
+    double *newbeta;
+    /* double *savediag*/
+    /* double temp; -Wall unused*/
     int halving, iter;
     double newlk;
-    int lastchance;
+    int lastchance=0;/*-Wall*/
 
     n = *nx;
     nvar = *nvarx;
@@ -404,8 +403,8 @@ static double dolik(int n, double *beta, int whichcase, void *fexpr1, void *fexp
     double  sig2;
     double  w;
     static double  funs[4], ufun[4];
-    double g, dg, ddg, dsig, ddsig, dsg;
-    int fgrp;
+    double g=0, dg=0, ddg=0, dsig=0, ddsig=0, dsg=0;
+    int fgrp=0;
 
     loglik=0;
     for (i=0; i<nf; i++) fdiag[i] =0;
